translate.tools.pretranslate

Package translate :: Package tools :: Module pretranslate |
[hide private]
[frames] | no frames]

# Module pretranslate

source code

Fill localization files with suggested translations based on translation memory and existing translations.

Functions | [hide private]
memory(tmfiles, max_candidates=1, min_similarity=75, max_length=1000) Returns the TM store to use. | source code
pretranslate_file(input_file, output_file, template_file, tm=None, min_similarity=75, fuzzymatching=True) Pretranslate any factory supported file with old translations and translation memory. | source code
match_template_location(input_unit, template_store) Returns a matching unit from a template. | source code
match_template_id(input_unit, template_store) Returns a matching unit from a template. | source code
match_source(input_unit, template_store) Returns a matching unit from a template. | source code
match_fuzzy(input_unit, matchers) Return a fuzzy match from a queue of matchers. | source code
pretranslate_unit(input_unit, template_store, matchers=None, mark_reused=False, match_locations=False) Pretranslate a unit or return unchanged if no translation was found. | source code
pretranslate_store(input_store, template_store, tm=None, min_similarity=75, fuzzymatching=True) Do the actual pretranslation of a whole store. | source code
main(argv=None) | source code

Variables | [hide private]
| tmmatcher = `None` hash(x)

Imports: factory, xliff, po, match

Function Details | [hide private]

### memory(tmfiles, max_candidates=1, min_similarity=75, max_length=1000) | source code
Returns the TM store to use. Only initialises on first call.

### match_template_location(input_unit, template_store) | source code
Returns a matching unit from a template. matching based on locations

### match_template_id(input_unit, template_store) | source code
Returns a matching unit from a template. matching based on unit id

### match_source(input_unit, template_store) | source code
Returns a matching unit from a template. matching based on unit id